TestRunnerOptions

Struct TestRunnerOptions 

pub struct TestRunnerOptions {
    pub wait_between_operations: Option<Duration>,
    pub index_wait_timeout: Option<Duration>,
}

Fields

wait_between_operations: Option<Duration>index_wait_timeout: Option<Duration>

Before a request that reads the search index (a search, conditional delete or conditional update), wait up to this long for the latest write to be indexed. Waits only as long as indexing takes, where wait_between_operations waits a fixed time after every operation.